@@ -11,11 +11,41 @@ use stm32l4xx_hal::{
     timer::Timer,
 };
 
-use atat::{AtatClient, ClientBuilder, ComQueue, Queues};
+use atat::{AtatClient, ClientBuilder, Clock, ComQueue, Queues};
 use rtic::{app, export::wfi};
 
 use heapless::spsc::Queue;
 
+struct AtClock<TIM, const TIMER_HZ: u32> {
+    _timer: Timer<TIM>,
+}
+
+impl<TIM, const TIMER_HZ: u32> AtClock<TIM, TIMER_HZ> {
+    fn new(timer: Timer<TIM>) -> Self {
+        Self { _timer: timer }
+    }
+}
+
+impl<TIM, const TIMER_HZ: u32> Clock<TIMER_HZ> for AtClock<TIM, TIMER_HZ> {
+    type Error = core::convert::Infallible;
+
+    fn now(&mut self) -> fugit::TimerInstantU32<TIMER_HZ> {
+        fugit::TimerInstantU32::from_ticks(0)
+    }
+
+    fn start(&mut self, _duration: fugit::TimerDurationU32<TIMER_HZ>) -> Result<(), Self::Error> {
+        Ok(())
+    }
+
+    fn cancel(&mut self) -> Result<(), Self::Error> {
+        Ok(())
+    }
+
+    fn wait(&mut self) -> nb::Result<(), Self::Error> {
+        Ok(())
+    }
+}
+
 #[app(device = stm32l4xx_hal::pac, peripherals = true)]
 const APP: () = {
     struct Resources {
@@ -56,6 +86,7 @@ const APP: () = {
         let rx = gpioa.pa3.into_af7(&mut gpioa.moder, &mut gpioa.afrl);
 
         let timer = Timer::tim7(p.TIM7, 1.hz(), clocks, &mut rcc.apb1r1);
+        let at_clock: AtClock<_, 1> = AtClock::new(timer);
 
         let mut serial = Serial::usart2(
             p.USART2,
@@ -75,7 +106,7 @@ const APP: () = {
 
         let (tx, rx) = serial.split();
         let (mut client, ingress) =
-            ClientBuilder::new(tx, timer, atat::Config::new(atat::Mode::Timeout)).build(queues);
+            ClientBuilder::new(tx, at_clock, atat::Config::new(atat::Mode::Timeout)).build(queues);
 
         ctx.spawn.at_loop().unwrap();
 
@@ -105,7 +136,7 @@ const APP: () = {
     #[task(binds = USART2, priority = 4, resources = [ingress, rx])]
     fn serial_irq(ctx: serial_irq::Context) {
         let rx = ctx.resources.rx;
-        if let Ok(d) = nb::block!(rx.try_read()) {
+        if let Ok(d) = nb::block!(rx.read()) {
             ctx.resources.ingress.write(&[d]);
         }
     }
