@@ -1,5 +1,4 @@
 use crate::{
-    atat_log,
     helpers::{get_line, LossyStr, SliceExt},
     urc_matcher::{UrcMatcher, UrcMatcherResult},
     InternalError,
@@ -82,7 +81,7 @@ impl Digester for DefaultDigester {
         }
 
         if !buf.is_empty() {
-            atat_log!(trace, "Digest {:?} / {:?}", self.state, LossyStr(buf));
+            trace!("Digest {:?} / {:?}", self.state, LossyStr(buf));
         }
 
         match self.state {
@@ -102,7 +101,7 @@ impl Digester for DefaultDigester {
                     {
                         self.state = State::ReceivingResponse;
                         self.buf_incomplete = false;
-                        atat_log!(trace, "Switching to state ReceivingResponse");
+                        trace!("Switching to state ReceivingResponse");
                     }
 
                 // Handle URCs
@@ -135,8 +134,7 @@ impl Digester for DefaultDigester {
                 // with "AT" or "+") can be ignored. Clear the buffer, but only if we can
                 // ensure that we don't accidentally break a valid response.
                 } else if self.buf_incomplete || buf.len() > 2 {
-                    atat_log!(
-                        error,
+                    error!(
                         "Clearing buffer with invalid response (incomplete: {}, buflen: {})",
                         self.buf_incomplete,
                         buf.len()
@@ -158,10 +156,10 @@ impl Digester for DefaultDigester {
                     );
 
                     if let Some(r) = removed {
-                        atat_log!(debug, "Cleared partial buffer, removed {:?}", LossyStr(&r));
+                        debug!("Cleared partial buffer, removed {:?}", LossyStr(&r));
                     } else {
                         buf.clear();
-                        atat_log!(debug, "Cleared partial buffer, removed everything");
+                        debug!("Cleared partial buffer, removed everything");
                     }
 
                     // If the buffer wasn't cleared completely, that means that
@@ -239,7 +237,7 @@ impl Digester for DefaultDigester {
                     return DigestResult::None;
                 };
 
-                atat_log!(trace, "Switching to state Idle");
+                trace!("Switching to state Idle");
                 self.state = State::Idle;
                 return DigestResult::Response(resp);
             }
