@@ -108,34 +108,6 @@ pub fn get_line<const L: usize, const I: usize>(
     }
 }
 
-#[cfg(feature = "log")]
-#[macro_export]
-macro_rules! atat_log {
-    ($level:ident, $($arg:expr),*) => {
-        log::$level!($($arg),*);
-    }
-}
-#[cfg(all(feature = "defmt", not(feature = "log")))]
-#[macro_export]
-macro_rules! atat_log {
-    ($level:ident, $($arg:expr),*) => {
-        defmt::$level!($($arg),*);
-    }
-}
-#[cfg(not(any(feature = "defmt", feature = "log")))]
-#[macro_export]
-macro_rules! atat_log {
-    ($level:ident, $($arg:expr),*) => {
-        {
-            $( let _ = $arg; )*
-            ()
-        }
-
-    }
-}
-#[cfg(all(feature = "defmt", feature = "log"))]
-compile_error!("You must enable at most one of the following features: defmt-*, log");
-
 /// Wrapper for a byte-slice that formats it as a string if possible and as
 /// bytes otherwise.
 pub struct LossyStr<'a>(pub &'a [u8]);
